==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/DeploymentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.DeploymentArgs.builder
import com.pulumi.azurenative.securityinsights.kotlin.enums.DeploymentResult
import com.pulumi.azurenative.securityinsights.kotlin.enums.DeploymentState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Description about a deployment.
 * @property deploymentId Deployment identifier.
 * @property deploymentLogsUrl Url to access repository action logs.
 * @property deploymentResult The outcome of the deployment.
 * @property deploymentState Current status of the deployment.
 * @property deploymentTime The time when the deployment finished.
 */
public data class DeploymentArgs(
    public val deploymentId: Output<String>? = null,
    public val deploymentLogsUrl: Output<String>? = null,
    public val deploymentResult: Output<Either<String, DeploymentResult>>? = null,
    public val deploymentState: Output<Either<String, DeploymentState>>? = null,
    public val deploymentTime: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.DeploymentArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.DeploymentArgs =
        com.pulumi.azurenative.securityinsights.inputs.DeploymentArgs.builder()
            .deploymentId(deploymentId?.applyValue({ args0 -> args0 }))
            .deploymentLogsUrl(deploymentLogsUrl?.applyValue({ args0 -> args0 }))
            .deploymentResult(
                deploymentResult?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .deploymentState(
                deploymentState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .deploymentTime(deploymentTime?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DeploymentArgs].
 */
@PulumiTagMarker
public class DeploymentArgsBuilder internal constructor() {
    private var deploymentId: Output<String>? = null

    private var deploymentLogsUrl: Output<String>? = null

    private var deploymentResult: Output<Either<String, DeploymentResult>>? = null

    private var deploymentState: Output<Either<String, DeploymentState>>? = null

    private var deploymentTime: Output<String>? = null

    /**
     * @param value Deployment identifier.
     */
    @JvmName("ddlsynrsyrshkphk")
    public suspend fun deploymentId(`value`: Output<String>) {
        this.deploymentId = value
    }

    /**
     * @param value Url to access repository action logs.
     */
    @JvmName("mjqholuenyteykad")
    public suspend fun deploymentLogsUrl(`value`: Output<String>) {
        this.deploymentLogsUrl = value
    }

    /**
     * @param value The outcome of the deployment.
     */
    @JvmName("sngivfnkwguxfmvn")
    public suspend fun deploymentResult(`value`: Output<Either<String, DeploymentResult>>) {
        this.deploymentResult = value
    }

    /**
     * @param value Current status of the deployment.
     */
    @JvmName("frumvoxiilnkehmx")
    public suspend fun deploymentState(`value`: Output<Either<String, DeploymentState>>) {
        this.deploymentState = value
    }

    /**
     * @param value The time when the deployment finished.
     */
    @JvmName("xswnggrnvotoxjbr")
    public suspend fun deploymentTime(`value`: Output<String>) {
        this.deploymentTime = value
    }

    /**
     * @param value Deployment identifier.
     */
    @JvmName("swjfbpmjiuqmwehi")
    public suspend fun deploymentId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentId = mapped
    }

    /**
     * @param value Url to access repository action logs.
     */
    @JvmName("wslfvjprhblalcch")
    public suspend fun deploymentLogsUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentLogsUrl = mapped
    }

    /**
     * @param value The outcome of the deployment.
     */
    @JvmName("dvryrbpyabtrosxn")
    public suspend fun deploymentResult(`value`: Either<String, DeploymentResult>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentResult = mapped
    }

    /**
     * @param value The outcome of the deployment.
     */
    @JvmName("afqydhbemoqypuxy")
    public fun deploymentResult(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeploymentResult>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deploymentResult = mapped
    }

    /**
     * @param value The outcome of the deployment.
     */
    @JvmName("cnwacxmeasyysbsx")
    public fun deploymentResult(`value`: DeploymentResult) {
        val toBeMapped = Either.ofRight<String, DeploymentResult>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deploymentResult = mapped
    }

    /**
     * @param value Current status of the deployment.
     */
    @JvmName("buvoowdkisklwqhq")
    public suspend fun deploymentState(`value`: Either<String, DeploymentState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentState = mapped
    }

    /**
     * @param value Current status of the deployment.
     */
    @JvmName("hkavreccnvjlhlce")
    public fun deploymentState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeploymentState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deploymentState = mapped
    }

    /**
     * @param value Current status of the deployment.
     */
    @JvmName("rssmphrxqvjjmqej")
    public fun deploymentState(`value`: DeploymentState) {
        val toBeMapped = Either.ofRight<String, DeploymentState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deploymentState = mapped
    }

    /**
     * @param value The time when the deployment finished.
     */
    @JvmName("vxhkvpxyslndasnq")
    public suspend fun deploymentTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentTime = mapped
    }

    internal fun build(): DeploymentArgs = DeploymentArgs(
        deploymentId = deploymentId,
        deploymentLogsUrl = deploymentLogsUrl,
        deploymentResult = deploymentResult,
        deploymentState = deploymentState,
        deploymentTime = deploymentTime,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/DeploymentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.DeploymentArgs.builder
import com.pulumi.azurenative.securityinsights.kotlin.enums.DeploymentResult
import com.pulumi.azurenative.securityinsights.kotlin.enums.DeploymentState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Description about a deployment.
 * @property deploymentId Deployment identifier.
 * @property deploymentLogsUrl Url to access repository action logs.
 * @property deploymentResult The outcome of the deployment.
 * @property deploymentState Current status of the deployment.
 * @property deploymentTime The time when the deployment finished.
 */
public data class DeploymentArgs(
    public val deploymentId: Output<String>? = null,
    public val deploymentLogsUrl: Output<String>? = null,
    public val deploymentResult: Output<Either<String, DeploymentResult>>? = null,
    public val deploymentState: Output<Either<String, DeploymentState>>? = null,
    public val deploymentTime: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.DeploymentArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.DeploymentArgs =
        com.pulumi.azurenative.securityinsights.inputs.DeploymentArgs.builder()
            .deploymentId(deploymentId?.applyValue({ args0 -> args0 }))
            .deploymentLogsUrl(deploymentLogsUrl?.applyValue({ args0 -> args0 }))
            .deploymentResult(
                deploymentResult?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .deploymentState(
                deploymentState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .deploymentTime(deploymentTime?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DeploymentArgs].
 */
@PulumiTagMarker
public class DeploymentArgsBuilder internal constructor() {
    private var deploymentId: Output<String>? = null

    private var deploymentLogsUrl: Output<String>? = null

    private var deploymentResult: Output<Either<String, DeploymentResult>>? = null

    private var deploymentState: Output<Either<String, DeploymentState>>? = null

    private var deploymentTime: Output<String>? = null

    /**
     * @param value Deployment identifier.
     */
    @JvmName("qcponikrojkpygul")
    public suspend fun deploymentId(`value`: Output<String>) {
        this.deploymentId = value
    }

    /**
     * @param value Url to access repository action logs.
     */
    @JvmName("rkcvdtmkngwyqbbs")
    public suspend fun deploymentLogsUrl(`value`: Output<String>) {
        this.deploymentLogsUrl = value
    }

    /**
     * @param value The outcome of the deployment.
     */
    @JvmName("ilxggwhgbevjxwxc")
    public suspend fun deploymentResult(`value`: Output<Either<String, DeploymentResult>>) {
        this.deploymentResult = value
    }

    /**
     * @param value Current status of the deployment.
     */
    @JvmName("ctieksiunxecbfsp")
    public suspend fun deploymentState(`value`: Output<Either<String, DeploymentState>>) {
        this.deploymentState = value
    }

    /**
     * @param value The time when the deployment finished.
     */
    @JvmName("ifmxtoatjasmxjfj")
    public suspend fun deploymentTime(`value`: Output<String>) {
        this.deploymentTime = value
    }

    /**
     * @param value Deployment identifier.
     */
    @JvmName("shloajgidbhtvjxp")
    public suspend fun deploymentId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentId = mapped
    }

    /**
     * @param value Url to access repository action logs.
     */
    @JvmName("fhhxebtthbvfttoq")
    public suspend fun deploymentLogsUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentLogsUrl = mapped
    }

    /**
     * @param value The outcome of the deployment.
     */
    @JvmName("ybqddsuwochitdvr")
    public suspend fun deploymentResult(`value`: Either<String, DeploymentResult>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentResult = mapped
    }

    /**
     * @param value The outcome of the deployment.
     */
    @JvmName("ckkorymqywtrkqan")
    public fun deploymentResult(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeploymentResult>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deploymentResult = mapped
    }

    /**
     * @param value The outcome of the deployment.
     */
    @JvmName("xqoksogwixxwgwff")
    public fun deploymentResult(`value`: DeploymentResult) {
        val toBeMapped = Either.ofRight<String, DeploymentResult>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deploymentResult = mapped
    }

    /**
     * @param value Current status of the deployment.
     */
    @JvmName("lxeqimuracxalieg")
    public suspend fun deploymentState(`value`: Either<String, DeploymentState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentState = mapped
    }

    /**
     * @param value Current status of the deployment.
     */
    @JvmName("wnofwrkkmiserivq")
    public fun deploymentState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeploymentState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deploymentState = mapped
    }

    /**
     * @param value Current status of the deployment.
     */
    @JvmName("oouqniyeptvhrmar")
    public fun deploymentState(`value`: DeploymentState) {
        val toBeMapped = Either.ofRight<String, DeploymentState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deploymentState = mapped
    }

    /**
     * @param value The time when the deployment finished.
     */
    @JvmName("rbmddvoarujpebik")
    public suspend fun deploymentTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentTime = mapped
    }

    internal fun build(): DeploymentArgs = DeploymentArgs(
        deploymentId = deploymentId,
        deploymentLogsUrl = deploymentLogsUrl,
        deploymentResult = deploymentResult,
        deploymentState = deploymentState,
        deploymentTime = deploymentTime,
    )
}
